| replaceValues | R Documentation |
Simple function to map a vector of values to another.
replaceValues(Source, Search, Replace)
Source |
A source of values to change. |
Search |
The values to search. |
Replace |
The equivalent values to replace. |
Simple function to map a vector of values another.
new values from a second vector.
Covarrubias-Pazaran G (2016) Genome assisted prediction of quantitative traits using the R package sommer. PLoS ONE 11(6): doi:10.1371/journal.pone.0156744
x <- letters[1:5]
y <- 1:5
z <- rep(letters[1:5],3)
replaceValues(Source=z, Search=x, Replace=y)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.